<?php

/**
 * ConvertKit Integration Class
 */

namespace Simple_Giveaways;

if ( ! defined( 'ABSPATH' ) ) {
	return;
}

if ( ! class_exists( '\Simple_Giveaways\GA_ConvertKit_Dummy' ) ) {
	class GA_ConvertKit_Dummy extends GA_Integration {

		/**
		 * Active Indicator
		 *
		 * @var boolean
		 */
		public $active = false;

		/**
		 * Integration Image
		 *
		 * @var string
		 */
		public $image = '';

		/**
		 * Integration Title
		 *
		 * @var string
		 */
		public $title = '';

		/**
		 * Integration Description
		 *
		 * @var string
		 */
		public $desc = '';

		/**
		 * API URL
		 *
		 * @var string
		 */
		private $api_url = 'https://api.convertkit.com/v3/';

		/**
		 * API Key
		 *
		 * @var string
		 */
		private $api_key = '';

		/**
		 * Request URL
		 *
		 * @var string
		 */
		private $request_url = '';

		/**
		 * Request Arguments
		 *
		 * @var array
		 */
		private $request_args = array();

		/**
		 * Metabox
		 *
		 * @var boolean
		 */
		private $metabox = false;

		/**
		 * Setting initial params
		 */
		public function __construct() {

			$this->title       = __( 'ConvertKit', 'giveasap' );
			$this->settings_id = 'ga_convertkit';
			$this->image       = untrailingslashit( GASAP_URI ) . '/includes/integrations/assets/convertkit-logo.png';
			$this->desc        = __( 'Sync your Giveaway subscribers to your ConvertKit list(s).', 'giveasap' );
		}

		public function buttons( $integrations ) {
			echo '<a href="' . esc_url( giv_fs()->get_upgrade_url() ) . '" class="button button-primary">' . esc_html__( 'Upgrade to PRO', 'giveasap' ) . '</a>';
		}

		/**
		 * Get Categories
		 *
		 * @return string[]
		 */
		public function get_categories() {
			return [
				'email',
				'marketing',
				'automation',
			];
		}
	}
}

add_filter( 'giveasap_integrations', '\Simple_Giveaways\giveasap_convertkit' );

/**
 * Registering ConvertKit Integration
 *
 * @return array
 */
function giveasap_convertkit( $integrations ) {

	$integrations['ga_convertkit'] = '\Simple_Giveaways\GA_ConvertKit_Dummy';

	return $integrations;
}
